@@ -12,7 +12,7 @@ from typedpy.structures import (
     NoneField,
     FinalStructure,
     ImmutableField,
-    unique
+    unique,
 )
 from typedpy.fields import (
     Number,
